==> resh-5.1.0.9-py3-none-any.whl: reface/static/js/common.js <==
const DALI1 = 'dali';
const DALI2 = 'dali2';

function check(e) {
    var changed = false;
    var submitBtn = null;
    $(e.currentTarget).find(':input').each(function () {
        if (this.getAttribute('type') === 'submit') {
            submitBtn = this;
        } else if (this.hasAttribute('def_value')) {
            changed = changed || this.value !== this.getAttribute('def_value');
        }
    });

    if (submitBtn) {
        if (changed) {
            $(submitBtn).removeClass('hidden');
        } else {
            $(submitBtn).addClass('hidden');
        }
    }

    if (e.currentTarget.hasAttribute('owner')) {
        const owner = $(e.currentTarget.getAttribute('owner') + ' .btn');
        if (owner.length > 0) {
            if (changed) {
                $(owner[0]).removeClass('hidden');
            } else {
                $(owner[0]).addClass('hidden');
            }
        }
    }
}

function onRefresh(e) {
    var btns = $('.left-buttons', '.main-panel-text-button').prevObject;
    for (var i=0; i < btns.length; i++ ) {
        btns[i].setAttribute('hidden', 'true');
    }
    btns = $('.right-buttons', '.main-panel-button').prevObject;
    for (i=0; i < btns.length; i++ ) {
        if (btns[i].className.indexOf('reloaderind') !== -1) {
            btns[i].removeAttribute('hidden');
        }
        else {
            btns[i].setAttribute('hidden', 'true');
        }
    }

    return true;
}

function form2data(form, formData) {
    formData = formData ? formData : {};

    function getValue(index, input) {
        if (input.style.display !== 'none' && input.name !== '' && input.value !== '') {
            if (input.type === 'checkbox') {
                formData[input.name] = input.checked;
            } else {
                formData[input.name] = isNaN(parseInt(input.value)) ? input.value : parseInt(input.value);
            }
        }
    }
    $(form).find("input").each(getValue);
    $(form).find("select").each(getValue);

    return formData;
}

function GET(name, def) {
    const url = window.location.href;
    name = name.replace(/[\[\]]/g, '\\$&');
    var regex = new RegExp('[?&]' + name + '(=([^&#]*)|&|#|$)'),
        results = regex.exec(url);
    if (!results) return def;
    if (!results[2]) return def;
    var res = decodeURIComponent(results[2].replace(/\+/g, ' '));
    if (res && res.indexOf(',') !== -1) return res.split(',');
    return Array.isArray(def) ? [res] : res;
}

==> resh-5.3.0.6-py3-none-any.whl: reface/static/js/common.js <==
const DALI1 = 'dali';
const DALI2 = 'dali2';

function check(e) {
    var changed = false;
    var submitBtn = null;
    $(e.currentTarget).find(':input').each(function () {
        if (this.getAttribute('type') === 'submit') {
            submitBtn = this;
        } else if (this.hasAttribute('def_value')) {
            changed = changed || this.value !== this.getAttribute('def_value');
        }
    });

    if (submitBtn) {
        if (changed) {
            $(submitBtn).removeClass('hidden');
        } else {
            $(submitBtn).addClass('hidden');
        }
    }

    if (e.currentTarget.hasAttribute('owner')) {
        const owner = $(e.currentTarget.getAttribute('owner') + ' .btn');
        if (owner.length > 0) {
            if (changed) {
                $(owner[0]).removeClass('hidden');
            } else {
                $(owner[0]).addClass('hidden');
            }
        }
    }
}

function onRefresh(e) {
    $('.left-buttons .main-panel-text-button').each((i, btn) => {
        btn.classList.add('hidden');
    });

    $('.right-buttons .main-panel-button').each((i, btn) => {
        if (btn.classList.contains('reloaderind')) {
            btn.classList.remove('hidden');
        } else {
            btn.classList.add('hidden');
        }
    });

    return true;
}

function form2data(form, formData) {
    formData = formData ? formData : {};

    function getValue(index, input) {
        if (input.style.display !== 'none' && input.name !== '' && input.value !== '') {
            if (input.type === 'checkbox') {
                formData[input.name] = input.checked;
            } else {
                formData[input.name] = isNaN(parseInt(input.value)) ? input.value : parseInt(input.value);
            }
        }
    }
    $(form).find("input").each(getValue);
    $(form).find("select").each(getValue);

    return formData;
}

function GET(name, def) {
    const url = window.location.href.toLowerCase();
    name = name.replace(/[\[\]]/g, '\\$&').toLowerCase();
    var regex = new RegExp('[?&]' + name + '(=([^&#]*)|&|#|$)'),
        results = regex.exec(url);
    if (!results) return def;
    if (!results[2]) return def;
    var res = decodeURIComponent(results[2].replace(/\+/g, ' '));
    if (res && res.indexOf(',') !== -1) return res.split(',');
    return Array.isArray(def) ? [res] : res;
}

function setCookie(name,value,days) {
    var expires = "";
    if (days) {
        var date = new Date();
        date.setTime(date.getTime() + (days * 24 * 60 * 60 * 1000));
        expires = "; expires=" + date.toUTCString();
    }
    document.cookie = name + "=" + (value || "") + expires + "; path=/";
}
function getCookie(name) {
    var nameEQ = name + "=";
    var ca = document.cookie.split(';');
    for(var i=0;i < ca.length;i++) {
        var c = ca[i];
        while (c.charAt(0)==' ') c = c.substring(1,c.length);
        if (c.indexOf(nameEQ) == 0) return c.substring(nameEQ.length,c.length);
    }
    return null;
}
function eraseCookie(name) {
    document.cookie = name +'=; Path=/; Expires=Thu, 01 Jan 1970 00:00:01 GMT;';
}
